Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: include.preload.js

Issue 5852174588313600: Issue 2602 - Don't use shadow DOM on mail.google.com, fixing an issue with the feedback form there (Closed)
Patch Set: Wrap line Created June 3, 2015, 3:31 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include.preload.js
===================================================================
--- a/include.preload.js
+++ b/include.preload.js
@@ -195,9 +195,12 @@
// However, creating a shadow root breaks running CSS transitions. So we
// have to create the shadow root before transistions might start (#452).
//
- // Also, we can't use shadow DOM on Google Docs, since it breaks printing
- // there (#1770).
- if ("createShadowRoot" in document.documentElement && document.domain != "docs.google.com")
+ // Also, we can't use shadow DOM on Google Docs since it breaks printing
+ // there (#1770), and Google Mail since the feedback from breaks the layout
+ // there when using shadow DOM (#2602).
+ if ("createShadowRoot" in document.documentElement
+ && document.domain != "docs.google.com"
+ && document.domain != "mail.google.com")
{
shadow = document.documentElement.createShadowRoot();
shadow.appendChild(document.createElement("shadow"));
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld